function ff = elliptic_wavefront_gauss_source ( s, t, xl, yl )

%*****************************************************************************80
%
%% ELLIPTIC_WAVEFRONT_GAUSS_SOURCE evaluates source terms at Gauss points. 
%
%  Modified:
%
%    05 November 2013
%
%  Parameters:
%
%          s         reference element x coordinate   
%          t         reference element y coordinate
%          xl        physical element x vertex coordinates 
%          yl        physical element y vertex coordinates  
%
% 
  nel=length(xl(:,1));
  zero_v = zeros(nel,1);
  xx=zero_v;
  yy=xx;
  [phi_e,dphids,dphidt] = shape(s,t);

  for ivtx=1:4 
    xx = xx + phi_e(ivtx) * xl(:,ivtx);
    yy = yy + phi_e(ivtx) * yl(:,ivtx);
  end

  ff = elliptic_wavefront_rhs ( xx, yy, nel );

  return
end

